/**
 * Installs a package
 *
 * @throws {@link Error} if the version is invalid
 * @throws {@link Error} if the exit code of npm install is not 0
 *
 * @example
```typescript
await npmInstall({
   packageName: 'typescript',
   version: 'latest',
   deepJsonFilePath,
   packageJsonFilePath,
})
```
 */
export declare function npmInstall(param: NpmInstallOptions): Promise<void>;
export interface NpmInstallOptions {
    /**
     * Package name to install
     */
    name: string;
    /**
     * Path to package.json
     */
    packageJsonFilePath?: string;
    /**
     * Path to deep.json
     */
    deepJsonFilePath?: string;
    /**
     * Version to install
     */
    version: string;
    /**
     * Path to package-lock.json
     */
    packageLockJsonFilePath?: string;
}
